import { jsx as _jsx } from "react/jsx-runtime";
import { useContext, useMemo } from 'react';
import { useRefExtra, useEvent } from '@react-devui/hooks';
import { DIconContext } from '@react-devui/icons/Icon';
import { getClassName } from '@react-devui/utils';
import dayjs from '../../dayjs';
import { DConfigContextManager } from './contex';
import { DConfigContext } from './contex';
import resources from './resources.json';
const ROOT = new DConfigContextManager({
    namespace: 'rd',
    componentConfigs: {},
    i18n: {
        lang: 'en-US',
        resources,
    },
    layout: {
        pageScrollEl: ':root',
    },
    globalScroll: false,
});
export const ROOT_DATA = {};
export function DRoot(props) {
    const { children, context: _context } = props;
    const parent = useContext(DConfigContext);
    const windowRef = useRefExtra(() => window);
    const [context, iconContext] = useMemo(() => {
        const context = new DConfigContextManager((parent !== null && parent !== void 0 ? parent : ROOT).mergeContext(_context !== null && _context !== void 0 ? _context : {}));
        if (parent) {
            context.setParent(parent);
        }
        const namespace = context.namespace;
        const iconProps = context.componentConfigs.DIcon;
        return [
            context,
            {
                props: iconProps,
                className: (theme) => getClassName(`${namespace}-icon`, { [`t-${theme}`]: theme }),
                twoToneColor: (theme) => [
                    theme ? `var(--${namespace}-color-${theme})` : `var(--${namespace}-text-color)`,
                    theme ? `var(--${namespace}-background-color-${theme})` : `rgb(var(--${namespace}-text-color-rgb) / 10%)`,
                ],
            },
        ];
    }, [_context, parent]);
    switch (context.i18n.lang) {
        case 'en-US':
            dayjs.locale('en');
            break;
        case 'zh-CN':
            dayjs.locale('zh-cn');
            break;
        default:
            break;
    }
    useEvent(windowRef, 'click', (e) => {
        // Check if click by keydown.
        if (!(e.clientX === 0 && e.clientY === 0)) {
            ROOT_DATA.clickEvent = {
                time: performance.now(),
                e,
            };
        }
    }, { capture: true });
    return (_jsx(DConfigContext.Provider, Object.assign({ value: context }, { children: parent ? children : _jsx(DIconContext.Provider, Object.assign({ value: iconContext }, { children: children })) })));
}
